#
# Hardware settings for Teclast F5 10" Laptop
# NixOS @ sda2
#
# flake.nix
#  └─ ./hosts
#      └─ ./laptop
#          └─ hardware-configuration.nix *
#
# Do not modify this file!  It was generated by ‘nixos-generate-config’
# and may be overwritten by future invocations.  Please make changes
# to /etc/nixos/configuration.nix instead.
{ config, lib, pkgs, modulesPath, ... }:

{
  imports =
    [ (modulesPath + "/installer/scan/not-detected.nix")
    ];

  boot.initrd.availableKernelModules = [ "nvme" "xhci_pci" "usb_storage" "usbhid" "sd_mod" "sdhci_pci" ];
  boot.initrd.kernelModules = [ ];
  boot.kernelModules = [ "kvm-amd" ];
  boot.kernelParams = [  ];
  boot.tmp.useTmpfs = true;
  zramSwap.enable = true;

  services.btrfs.autoScrub = {
    enable = true;
    interval = "monthly";
    fileSystems = [
      "/"
    ];
  };

  services.btrbk = {
      instances = {
          hf = {
              onCalendar = "hourly";
              settings = {
                  incremental = "yes";
                  snapshot_create = "ondemand";
                  snapshot_dir = "@snapshots";
                  timestamp_format = "long";

                  snapshot_preserve = "2m 2w 5d 5h";
                  snapshot_preserve_min = "latest";
                
                  volume =  {
                      "/mnt/snapshots/root" = {
                          snapshot_create = "always";
                          subvolume = {
                              "@home" = {};
                          };
                      };
                  };
              };
          };
      };
  };

  fileSystems."/" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@,discard=async" ];
    };

  fileSystems."/home" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@home,discard=async" ];
    };

  fileSystems."/srv" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@srv,discard=async" ];
    };

  fileSystems."/nix" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@nix,discard=async" ];
    };

  fileSystems."/mnt/snapshots/root" =
    { device = "/dev/disk/by-label/NIXROOT";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvolid=5,discard=async" ];
    };

  fileSystems."/boot" =
    { device = "/dev/disk/by-label/NIXBOOT";
      fsType = "vfat";
    };

  fileSystems."/sdcard" =
    { device = "/dev/disk/by-label/sdcard";
      fsType = "ext4";
      options = [ "nofail" "x-systemd.automount" ];
    };

  fileSystems."/mnt/Pluto" =
    { device = "nas:/Pluto";
      fsType = "nfs";
      options = [ "noauto,users,x-systemd.automount,x-systemd.device-timeout=10,soft,timeo=14,x-systemd.idle-timeout=1min,sec=sys,exec,nfsvers=4.2" ];
    };

  fileSystems."/mnt/Mars" =
    { device = "nas:/Mars";
      fsType = "nfs";
      options = [ "noauto,users,x-systemd.automount,x-systemd.device-timeout=10,soft,timeo=14,x-systemd.idle-timeout=1min,sec=sys,exec,nfsvers=4.2" ];
    };


  swapDevices = [
    { device = "/dev/disk/by-label/NIXSWAP"; }
  ];
  

  networking = {
    useDHCP = false;                        # Deprecated
    hostName = "nix-steamdeck";
    wireless.iwd.enable = true;
    networkmanager = {
      enable = true;
      wifi = {
        backend = "iwd";
        powersave = true;
      };
    };
#    interfaces = {
#      wlan0 = {
#        useDHCP = true;                     # For versatility sake, manually edit IP on nm-applet.
#        #ipv4.addresses = [ {
#        #    address = "192.168.0.51";
#        #    prefixLength = 24;
#        #} ];
#      };
#    };
    #defaultGateway = "192.168.0.1";
    #nameservers = [ "192.168.0.4" ];
    firewall = {
      checkReversePath = "loose";
    #  enable = false;
    #  #allowedUDPPorts = [ 53 67 ];
    #  #allowedTCPPorts = [ 53 80 443 9443 ];
    };
  };

  hardware.cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
